@@ -2,13 +2,14 @@
 
 packname="0-init-simple-pack"
 
-$DUB init $packname
+$DUB init -n $packname --format sdl
 
 function cleanup {
     rm -rf $packname
 }
 
 if [ ! -e $packname/dub.sdl ]; then # it failed
+    echo "No dub.sdl file has been generated."
     cleanup
     exit 1
 fi
